pub enum FileConcatResult {
Written(FileConcatOutput),
Reused(usize, FileConcatOutput),
Unsupported(FileConcatReason),
}Expand description
Result of one encoded-file concatenation attempt.
Variants
Written(FileConcatOutput)
A new ordinary Lance file was written.
Reused(usize, FileConcatOutput)
One compatible complete input already is the requested output.
Unsupported(FileConcatReason)
Compatibility was rejected before the output factory was called.