pub struct BlobTargetId(/* private fields */);Expand description
Caller-defined runtime identity of the final target for Blob-bearing parts.
Lance only compares this value when assembling data-file parts. It does not interpret it as a dataset, base, or object-store identity, persist it, or define a recovery protocol for it. The caller must provide the same identity for every part and target that belong to one assembly operation.
Implementations