pub struct FieldsWithMeta {
pub fields: Fields,
pub metadata: HashMap<String, Vec<u8>>,
}Fields
fields: Fieldsmetadata: HashMap<String, Vec<u8>>Trait Implementations
Sourceimpl From<&Schema> for FieldsWithMeta
Convert a Schema to a list of protobuf Field and Metadata
impl From<&Schema> for FieldsWithMeta
Convert a Schema to a list of protobuf Field and Metadata
Sourceimpl TryFrom<FieldsWithMeta> for Schema
Reconstruct a schema from flat protobuf fields and schema metadata.
impl TryFrom<FieldsWithMeta> for Schema
Reconstruct a schema from flat protobuf fields and schema metadata.
Examples
use std::collections::HashMap;
use lance_core::datatypes::Schema;
use lance_file::datatypes::{Fields, FieldsWithMeta};
let fields = FieldsWithMeta {
fields: Fields(Vec::new()),
metadata: HashMap::from([("owner".to_owned(), b"lance".to_vec())]),
};
let schema = Schema::try_from(fields)?;
assert_eq!(schema.metadata["owner"], "lance");Auto Trait Implementations
impl Freeze for FieldsWithMeta
impl RefUnwindSafe for FieldsWithMeta
impl Send for FieldsWithMeta
impl Sync for FieldsWithMeta
impl Unpin for FieldsWithMeta
impl UnsafeUnpin for FieldsWithMeta
impl UnwindSafe for FieldsWithMeta