Module version

Module version 

Enums

ConcreteFileVersion
The exact persisted identity of a Lance file format.
LanceFileVersion
A caller-facing Lance file-version request.

Constants

LEGACY_FORMAT_VERSION
V2_FORMAT_2_0
V2_FORMAT_2_1
V2_FORMAT_2_2
V2_FORMAT_2_3

Functions

next_file_version
Resolve the current next release policy to an exact file version.
stable_file_version
Resolve the current stable release policy to an exact file version.