Enums
- Concrete
File Version - The exact persisted identity of a Lance file format.
- Lance
File Version - A caller-facing Lance file-version request.
Constants
Functions
- next_
file_ version - Resolve the current next release policy to an exact file version.
- stable_
file_ version - Resolve the current stable release policy to an exact file version.